# Player control
#
# plugin name:
#       player
#
# available options:
#       :player - available options:
#                       amarok
#                       songbird (requires plugin)
#                       moc
#                       exaile
#                       cmus
#
#       :seek_time - number of seconds for rewind and fast forward
#                    (default is 10)
#
# available commands:
#       rewind   - seek back for t (optional) seconds (default is 10)
#       fforward - seek forward fot t (optional) seconds (default is 10)
#       pause    - play/pause toggle
#       stop
#       prev
#       next
#       stop
#
#   Note: rewind and fforward are not available in songbird and exaile
#       

#
# Copyright 2010 Igor Brkic <igor@hyperglitch.com>
#

class Player

    def initialize io
        @io=io
    end

    def setup options
        @player=options[:player]||''
        t=options[:seek_time]||10

        @cmds={
            "amarok" => {
                'prev'    =>"dcop amarok player prev",
                'rewind'  =>"dcop amarok player seekRelative -#{t}",
                'play'    =>"dcop amarok player playPause",
                'pause'   =>"dcop amarok player playPause",
                'stop'    =>"dcop amarok player stop",
                'fforward'=>"dcop amarok player seekRelative #{t}",
                'next'    =>"dcop amarok player next"
            },
            "songbird" => {
                'prev'    =>"songbird -prev",
                'rewind'  =>"",
                'play'    =>"songbird -play",
                'pause'   =>"songbird -pause",
                'stop'    =>"songbird -stop",
                'fforward'=>"",
                'next'    =>"songbird -next"
            },
            "moc" => {
                'prev'    =>"mocp --previous",
                'rewind'  =>"mocp --seek -#{t}",
                'play'    =>"mocp --play",
                'pause'   =>"mocp --toggle-pause",
                'stop'    =>"mocp --stop",
                'fforward'=>"mocp --seek #{t}",
                'next'    =>"mocp --next"
            },
            "exaile" => {
                'prev'    =>"exaile --prev",
                'rewind'  =>"",
                'play'    =>"exaile --play",
                'pause'   =>"exaile --play-pause",
                'stop'    =>"exaile --stop",
                'fforward'=>"",
                'next'    =>"exaile --next"
            },
            "cmus" => {
                'prev'    =>"/usr/local/bin/cmus-remote --prev",
                'rewind'  =>"/usr/local/bin/cmus-remote --seek -5",
                'play'    =>"/usr/local/bin/cmus-remote --play",
                'pause'   =>"/usr/local/bin/cmus-remote --pause",
                'stop'    =>"/usr/local/bin/cmus-remote --stop",
                'fforward'=>"/usr/local/bin/cmus-remote --seek +5",
                'next'    =>"/usr/local/bin/cmus-remote --next"
            }
        }
    end

    def player_control cmd
        system @cmds[@player][cmd]+' &' if @cmds[@player].member? cmd
        @io.log "[Player] "+cmd
    end

    def run action=[]
        if action.empty? then
            # display a menu with options
            player_control @io.input(@cmds[@player].keys, "[Player]")
        else
            player_control action[0]
        end
    end
end
