
# Sample plugin
# simple demonstration how to write a plugin
#
#
# available options:
#       available configuration options
#       (these will be passed as Hash to setup method)
#
# available commands:
#       available run commands
#       (these will be passed as array to run method)
#
#
# Plugins are normal Ruby classes that must implement following three methods:
#       initialize - constructor that will receive copy of input/output
#                    object as an argument
#
#       setup      - this method will be called on startup and on every
#                    reload of configuration file
#
#       run        - this method will be called when user selects plugin
#                    from menu or sends it's name as a request. If it is
#                    selected from menu :action patameter will be passed
#                    as an action. If it is directly called, everything
#                    after plugin's name will be split into array and sent
#                    (for example: request "sample bla bli blu" will call 
#                    sample's run method with argument ["bla", "bli". "blu"])
#
# You can also add any number of your own methods.
#
# On initialization a copy of MenuIO object is passed. MenuIO object currently
# has four public methods: input, output, log and bar.
#
# MenuIO::input is used for dmenu user input. Its prototype is:
#   String MenuIO::input(list, txt)
#       
#       list - array of values to be chosen from (required, can be ampty array)
#       txt  - optional text to be shown at the prompt
#
#       input returns string with user input. If user presses escape, empty string
#       is returned
#
# MenuIO::output outputs text to screen using dzen2.
#   MenuIO::output(txt)
#
#       txt - text to be displayed. All dzen formatting is supported (see 
#             dzen2 README file for more info)
#
# MenuIO::log sends text to log. Logging can be configured in main config file.
#   MenuIO::log(txt)
#
#       txt - text to be sent to log. It is nice to prefix any messages with
#             plugin name in brackets (for example "[Sample] status updated")
#
# MenuIO::bar is helper method for creating progress bar formatted for dzen.
# Progress bar colors are defined in main config file.
#   String MenuIO::bar(perc, txt='', icon=nil)
#
#       perc - percentage to be displayed
#       txt  - optional text before progress bar
#       icon - icon to be displayed before text. Icon can be string containing
#              name of the icon (with extension) in the icons folder or array of 
#              icon names.
#              If icon is array, this method will decide which icon to use
#              depending on the perc value (there can be icon for low values,
#              medium values and high values)
#
# Icons and data (if necessary) are usually put in modules/icons and 
# modules/data directories.
#

#
# Copyright <year> <name> <mail>
#

# class name must be same as file name and first letter must be capitalized
class PluginSample

    # object constructor
    def initialize io
        @io=io
    end

    # method that will be called upon startup and also when reloading
    # config file
    def setup options

        @var1 = options[:option1] || 'var1 default value'
        # ...

    end

    # main method that is called when plugin is executed
    def run action=[]

    end
end
